# -*- coding: utf-8 -*-
import logging

from .api.config import Config
from .errors import APIError, ConfigurationError, ArgumentMissingError

from .api.ping import Ping
from .api.data_source import DataSource
from .api.plan import Plan
from .api.customer import Customer
from .api.attributes import Attributes
from .api.tags import Tags
from .api.activity import Activity
from .api.subscription import Subscription
from .api.metrics import Metrics
from .api.custom_attrs import CustomAttributes

# Can't merge modules, because of Subscription clash.
import imp


"""
ChartMogul API Python Client

Provides convenient Python bindings for ChartMogul's API.

:copyright: (c) 2017 by ChartMogul Ltd.
:license: MIT, see LICENSE for more details.
"""

__title__ = 'chartmogul'
__version__ = '1.0.0'
__build__ = 0x000000
__author__ = 'ChartMogul Ltd'
__license__ = 'MIT'
__copyright__ = 'Copyright 2017 ChartMogul Ltd'
